/**
 * 
 */
package com.rjconsultores.ventaboletos.relatorios.impl;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.Timestamp;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import com.rjconsultores.ventaboletos.relatorios.utilitarios.ArrayDataSource;
import com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio;
import com.rjconsultores.ventaboletos.utilerias.DateUtil;
import com.rjconsultores.ventaboletos.web.utilerias.NamedParameterStatement;

/**
 * @author Bruno Neves
 *
 */
public class RelatorioCancelamentoAutomaticoECF extends Relatorio {


	public RelatorioCancelamentoAutomaticoECF(Map<String, Object> parametros, Connection conexao) throws Exception {
		super(parametros, conexao);

		this.setCustomDataSource(new ArrayDataSource(this) {
			@Override
			public void initDados() throws Exception {

				Connection conexao = this.relatorio.getConexao();
				Map<String, Object> parametros = this.relatorio.getParametros();

				StringBuilder sql = new StringBuilder();
				
				sql.append(" SELECT c.CORRIDA_ID AS Servico ,  ");
				sql.append("   c.RUTA_ID         AS Linhas,  ");
				sql.append("   c.PUNTOVENTA_ID   AS agencia , ");
				sql.append("   pOrigem.DESCPARADA AS origem, ");
				sql.append("   pDestino.DESCPARADA AS destino, ");
				sql.append("   c.NUMASIENTO AS poltronas, ");
				sql.append("   c.NUMFOLIOSISTEMA AS passagem, ");
				sql.append("   cs.DESCCLASE AS classe, ");
				sql.append("   c.USUARIO_ID AS bilheteiro, ");
				sql.append("   c.FECHORVENTA AS dataVenda, ");
				sql.append("   c.PRECIOPAGADO AS tarifa, ");
				sql.append("   c.IMPORTETAXAEMBARQUE AS taxa, ");
				sql.append("   c.IMPORTEPEDAGIO AS pedagio, ");
				sql.append("   c.IMPORTESEGURO AS seguro, ");
				sql.append("   c.FECHORVIAJE AS dataEmbarque, ");
				sql.append("   c.NUMFOLIOPREIMPRESO AS preImpresso, ");
				sql.append("   fr4.NUMSERIE20 AS impressora, ");
				sql.append("   e.NOMBEMPRESA AS empresa, ");
				sql.append("   fp.DESCPAGO AS formaPagamento, ");
				sql.append("   ROUND((100 * cfp.importe) / (coalesce(c.preciopagado,0)+coalesce(c.importetaxaembarque,0)+coalesce(c.importeseguro,0)+coalesce(c.importepedagio,0)+coalesce(c.importeoutros,0)),2)  as porcentagem , ");
				sql.append("   ct.NSU AS nsu, ");
				sql.append("   ct.NUMAUTORIZACION AS autorizacao ");
				sql.append(" FROM FISCAL_R4 fr4 ");
				sql.append(" INNER JOIN caja c ");
				sql.append(" ON c.CAJA_ID = fr4.CAJA_ID ");
				sql.append(" INNER JOIN parada pOrigem ");
				sql.append(" ON pOrigem.PARADA_ID = c.ORIGEN_ID ");
				sql.append(" INNER JOIN parada pDestino ");
				sql.append(" ON pDestino.PARADA_ID = c.DESTINO_ID ");
				sql.append(" INNER JOIN CLASE_SERVICIO cs ");
				sql.append(" ON cs.CLASESERVICIO_ID  = c.CLASESERVICIO_ID ");
				sql.append(" INNER JOIN EMPRESA e ");
				sql.append(" ON e.EMPRESA_ID  = c.EMPRESACORRIDA_ID ");
				sql.append(" INNER JOIN CAJA_FORMAPAGO cfp ");
				sql.append(" ON cfp.CAJA_ID = c.CAJA_ID ");
				sql.append(" INNER JOIN FORMA_PAGO fp ");
				sql.append(" ON fp.FORMAPAGO_ID = cfp.FORMAPAGO_ID ");
				sql.append(" INNER JOIN CAJA_DET_PAGO cdp ");
				sql.append(" ON cdp.CAJAFORMAPAGO_ID = cfp.CAJAFORMAPAGO_ID ");
				sql.append(" INNER JOIN CAJA_TARJETA ct ");
				sql.append(" ON ct.CAJADETPAGO_ID = cdp.CAJADETPAGO_ID ");
				sql.append(" WHERE fr4.INDCANCELAMENTO = 'S' ");
				//sql.append(" and to_date(fr4.DATAMOV,'yyyyMMdd') between to_date(:DATA_INICIAL,'dd/MM/yyyy') and to_date(:DATA_FINAL,'dd/MM/yyyy')");
				sql.append(" and to_date(fr4.DATAMOV,'yyyyMMdd') >= :DATA_INICIAL ");
				sql.append(" and to_date(fr4.DATAMOV,'yyyyMMdd') <= :DATA_FINAL ");
				
				if(parametros.get("EMPRESA_ID") != null){
					sql.append(" and c.EMPRESAPUNTOVENTA_ID = :EMPRESA_ID");
				}
				
				if (parametros.get("NUMPUNTOVENTA") != null) {
					sql.append(" and c.puntoventa_id IN (" + parametros.get("NUMPUNTOVENTA").toString() + ")");
				}
					
				sql.append(" order by fr4.CAJA_ID, cfp.CAJAFORMAPAGO_ID ");
				
				NamedParameterStatement stmt = new NamedParameterStatement(conexao, sql.toString());
				if(parametros.get("EMPRESA_ID") != null){
					stmt.setInt("EMPRESA_ID", Integer.valueOf(parametros.get("EMPRESA_ID").toString()));
				}
				
				stmt.setTimestamp("DATA_INICIAL", new Timestamp(DateUtil.inicioFecha((Date) parametros.get("DATA_INICIAL")).getTime()));
				stmt.setTimestamp("DATA_FINAL", new Timestamp(DateUtil.fimFecha((Date) parametros.get("DATA_FINAL")).getTime()));
				
				if(parametros.get("TIPOPUNTOVENTA_ID") != null && !parametros.get("TIPOPUNTOVENTA_ID").toString().equals("-1") ){
					stmt.setInt("TIPOPUNTOVENTA_ID", Integer.valueOf(parametros.get("TIPOPUNTOVENTA_ID").toString()));
				}
				
				ResultSet rset = stmt.executeQuery();

				while (rset.next()) {

					Map<String, Object> dataResult = new HashMap<String, Object>();

					dataResult.put("servico", rset.getString("servico"));
					dataResult.put("linhas", rset.getString("linhas"));
					dataResult.put("agencia", rset.getString("agencia"));
					dataResult.put("origem", rset.getString("origem"));
					dataResult.put("destino", rset.getString("destino"));
					dataResult.put("poltronas", rset.getString("poltronas"));
					dataResult.put("passagem", rset.getString("passagem"));
					dataResult.put("classe", rset.getString("classe"));
					dataResult.put("bilheteiro", rset.getString("bilheteiro"));
					dataResult.put("dataVenda", rset.getString("dataVenda"));
					dataResult.put("tarifa", rset.getString("tarifa"));
					dataResult.put("taxa", rset.getString("taxa"));
					dataResult.put("pedagio", rset.getString("pedagio"));
					dataResult.put("seguro", rset.getString("seguro"));
					dataResult.put("dataEmbarque", rset.getString("dataEmbarque"));
					dataResult.put("preImpresso", rset.getString("preImpresso"));
					dataResult.put("impressora", rset.getString("impressora"));
					dataResult.put("empresa", rset.getString("empresa"));
					dataResult.put("formaPagamento", rset.getString("formaPagamento"));
					dataResult.put("porcentagem", rset.getString("porcentagem"));
					dataResult.put("nsu", rset.getString("nsu"));
					dataResult.put("autorizacao", rset.getString("autorizacao"));
					this.dados.add(dataResult);

				}

				this.resultSet = rset;
			}
		});
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see com.rjconsultores.ventaboletos.relatorios.utilitarios.Relatorio#processaParametros()
	 */
	@Override
	protected void processaParametros() throws Exception {

	}

}
